@@ -6,7 +6,7 @@ from kgcnn.data.download import DownloadDataset
 
 class GraphTUDataset2020(GraphTUDataset, DownloadDataset):
     r"""Base class for loading graph datasets published by `TU Dortmund University
-    <https://chrsmrrs.github.io/datasets>`_.
+    <https://chrsmrrs.github.io/datasets>`_ .
 
     This general base class has functionality to load TUDatasets in a generic way.
 
@@ -56,13 +56,13 @@ class GraphTUDataset2020(GraphTUDataset, DownloadDataset):
         "COLORS-3", "SYNTHETIC", "SYNTHETICnew", "Synthie", "TRIANGLES"
     ]
 
-    def __init__(self, dataset_name: str, reload: bool = False, verbose: int = 1):
+    def __init__(self, dataset_name: str, reload: bool = False, verbose: int = 10):
         """Initialize a `GraphTUDataset` instance from string identifier.
 
         Args:
             dataset_name (str): Name of a dataset.
             reload (bool): Download the dataset again and prepare data on disk.
-            verbose (int): Print progress or info for processing, where 0 is silent. Default is 1.
+            verbose (int): Print progress or info for processing where 60=silent. Default is 10.
         """
         if not isinstance(dataset_name, str):
             raise ValueError("Please provide string identifier for TUDataset.")
