@@ -2,7 +2,7 @@ from kgcnn.data.datasets.MatBenchDataset2020 import MatBenchDataset2020
 
 
 class MatProjectEFormDataset(MatBenchDataset2020):
-    r"""Store and process :obj:`MatProjectEFormDataset` from `MatBench <https://matbench.materialsproject.org/>`_
+    r"""Store and process :obj:`MatProjectEFormDataset` from `MatBench <https://matbench.materialsproject.org/>`__
     database.  Name within Matbench: 'matbench_mp_e_form'.
 
     Matbench test dataset for predicting DFT formation energy from structure.
@@ -17,12 +17,12 @@ class MatProjectEFormDataset(MatBenchDataset2020):
 
     """
 
-    def __init__(self, reload=False, verbose=1):
+    def __init__(self, reload=False, verbose: int = 10):
         r"""Initialize 'matbench_mp_e_form' dataset.
 
         Args:
             reload (bool): Whether to reload the data and make new dataset. Default is False.
-            verbose (int): Print progress or info for processing where 0=silent. Default is 1.
+            verbose (int): Print progress or info for processing where 60=silent. Default is 10.
         """
         # Use default base class init()
         super(MatProjectEFormDataset, self).__init__("matbench_mp_e_form", reload=reload, verbose=verbose)
