@@ -5,14 +5,14 @@ from kgcnn.data.download import DownloadDataset
 
 
 class MoleculeNetDataset2018(MoleculeNetDataset, DownloadDataset):
-    r"""Downloader for `MoleculeNet <https://moleculenet.org/>`_ datasets.
+    r"""Downloader for `MoleculeNet <https://moleculenet.org/>`__ datasets.
     This class inherits from :obj:`MoleculeNetDataset` .
     QM datasets are however excluded from this class as they have specific `kgcnn.data.datasets` which inherits from
     :obj:`QMDatasets` .
 
     MoleculeNet is a benchmark specially designed for testing machine learning methods of molecular properties.
     Their work curates a number of dataset collections. All methods and datasets are integrated as parts
-    of the open source `DeepChem <https://deepchem.io/>`_ package (MIT license).
+    of the open source `DeepChem <https://deepchem.io/>`__ package (MIT license).
 
     Stats:
         .. list-table::
@@ -130,13 +130,13 @@ class MoleculeNetDataset2018(MoleculeNetDataset, DownloadDataset):
         "ClinTox": {"add_hydrogen": False, "has_conformers": True,  "label_column_name": [1, 2]}
     }
 
-    def __init__(self, dataset_name: str, reload: bool = False, verbose: int = 1):
+    def __init__(self, dataset_name: str, reload: bool = False, verbose: int = 10):
         """Initialize a `MoleculeNetDataset2018` instance from string identifier.
 
         Args:
             dataset_name (str): Name of a dataset.
             reload (bool): Download the dataset again and prepare data on disk.
-            verbose (int): Print progress or info for processing, where 0 is silent. Default is 1.
+            verbose (int): Print progress or info for processing where 60=silent. Default is 10.
         """
         if not isinstance(dataset_name, str):
             raise ValueError("Please provide string identifier for TUDataset.")
