@@ -5,9 +5,9 @@ from kgcnn.data.download import DownloadDataset
 
 
 class QM8Dataset(QMDataset, DownloadDataset):
-    r"""Store and process QM8 dataset from `MoleculeNet <https://moleculenet.org/>`_ datasets.
+    r"""Store and process QM8 dataset from `MoleculeNet <https://moleculenet.org/>`__ datasets.
 
-    From `Quantum Machine <http://quantum-machine.org/datasets/>`_ :
+    From `Quantum Machine <http://quantum-machine.org/datasets/>`__ :
     Due to its favorable computational efficiency, time-dependent (TD) density functional theory(DFT) enables
     the prediction of electronic spectra in a high-throughput manner across chemical space. Its predictions,
     however, can be quite inaccurate. We resolve this issue with machine learning models trained on deviations of
@@ -43,12 +43,12 @@ class QM8Dataset(QMDataset, DownloadDataset):
         "unpack_directory_name": "gdb8"
     }
 
-    def __init__(self, reload: bool = False, verbose: int = 1):
+    def __init__(self, reload: bool = False, verbose: int = 10):
         """Initialize QM8 dataset.
 
         Args:
             reload (bool): Whether to reload the data and make new dataset. Default is False.
-            verbose (int): Print progress or info for processing where 0=silent. Default is 1.
+            verbose (int): Print progress or info for processing where 60=silent. Default is 10.
         """
         QMDataset.__init__(self, verbose=verbose, dataset_name="QM8")
         DownloadDataset.__init__(self, **self.download_info, reload=reload, verbose=verbose)
