@@ -10,11 +10,11 @@ from kgcnn.mol.io import write_list_to_xyz_file
 
 
 class QM9Dataset(QMDataset, DownloadDataset):
-    r"""Store and process QM9 dataset from `Quantum Machine <http://quantum-machine.org/datasets/>`_ . dataset.
+    r"""Store and process QM9 dataset from `Quantum Machine <http://quantum-machine.org/datasets/>`__ . dataset.
 
     Dataset of 134k stable small organic molecules made up of C,H,O,N,F.
 
-    From `Quantum Machine <http://quantum-machine.org/datasets/>`_ :
+    From `Quantum Machine <http://quantum-machine.org/datasets/>`__ :
     Computational de novo design of new drugs and materials requires rigorous and unbiased exploration of chemical
     compound space. However, large uncharted territories persist due to its size scaling combinatorially with
     molecular size. We report computed geometric, energetic, electronic, and thermodynamic properties for 134k stable
@@ -61,12 +61,12 @@ class QM9Dataset(QMDataset, DownloadDataset):
         "unpack_directory_name": 'dsgdb9nsd.xyz',
     }
 
-    def __init__(self, reload: bool = False, verbose: int = 1):
+    def __init__(self, reload: bool = False, verbose: int = 10):
         """Initialize QM9 dataset.
 
         Args:
             reload (bool): Whether to reload the data and make new dataset. Default is False.
-            verbose (int): Print progress or info for processing where 0=silent. Default is 1.
+            verbose (int): Print progress or info for processing where 60=silent. Default is 10.
         """
         QMDataset.__init__(self, verbose=verbose, dataset_name="QM9")
         DownloadDataset.__init__(self, **self.download_info, reload=reload, verbose=verbose)
