@@ -1,7 +1,7 @@
 import tensorflow as tf
 from kgcnn.layers.base import GraphBaseLayer
 from kgcnn.ops.partition import partition_row_indexing
-from kgcnn.ops.axis import get_positive_axis
+# from kgcnn.ops.axis import get_positive_axis
 ks = tf.keras
 
 
@@ -21,6 +21,7 @@ class GatherEmbedding(GraphBaseLayer):
     by setting :obj:`split_axis` or :obj:`concat_axis` if index shape is known during build.
 
     .. note:
+
         Default of this layer is concatenation with :obj:`concat_axis=2`.
 
     Example of usage for :obj:`GatherEmbedding`:
@@ -30,12 +31,16 @@ class GatherEmbedding(GraphBaseLayer):
         nodes = tf.ragged.constant([[[0.0],[1.0]],[[2.0],[3.0],[4.0]]], ragged_rank=1)
         edge_idx = tf.ragged.constant([[[0,1],[1,0]],[[0,2],[1,2]]], ragged_rank=1)
         print(GatherEmbedding()([nodes, edge_idx]))
+
     """
 
     def __init__(self,
                  axis: int = 1,
                  concat_axis: int = 2,
                  split_axis: int = None,
+                 split_indices: list = None,
+                 concat_indices: list = None,
+                 node_indexing: str = "sample",
                  **kwargs):
         r"""Initialize layer.
 
@@ -48,6 +53,9 @@ class GatherEmbedding(GraphBaseLayer):
         self.concat_axis = concat_axis
         self.axis = axis
         self.split_axis = split_axis
+        self.split_indices = split_indices
+        self.concat_indices = concat_indices
+        self.node_indexing = node_indexing
 
         if split_axis is not None and concat_axis is not None:
             raise ValueError("Can not both split and concatenate new index axis. At least one must be `None`.")
@@ -56,7 +64,40 @@ class GatherEmbedding(GraphBaseLayer):
         super(GatherEmbedding, self).build(input_shape)
 
         if len(input_shape) != 2:
-            print("Number of inputs for layer %s is expected to be 2." % self.name)
+            print("Number of inputs for layer '%s' must be 2: `[nodes, indices]` ." % self.name)
+
+    def _disjoint_implementation(self, inputs, **kwargs):
+        # The primary case for aggregation of nodes from node feature list. Case from doc-string.
+        # Possibly faster implementation via values and indices shifted by row-partition.
+        # Equal to disjoint implementation. Only works for ragged_rank=1 and specific axis.
+        if all([isinstance(x, tf.RaggedTensor) for x in inputs]):
+            is_rank_one = all([x.ragged_rank == 1 for x in inputs])
+            if is_rank_one and self.axis == 1 and self.concat_axis in [None, 2] and self.split_axis in [None, 2]:
+                node, node_part = inputs[0].values, inputs[0].row_splits
+                edge_index, edge_part = inputs[1].values, inputs[1].row_lengths()
+                disjoint_list = partition_row_indexing(edge_index, node_part, edge_part,
+                                                       partition_type_target="row_splits",
+                                                       partition_type_index="row_length",
+                                                       to_indexing='batch',
+                                                       from_indexing=self.node_indexing)
+                out = tf.gather(node, disjoint_list, axis=0)
+                # Option: Concat features.
+                if self.concat_axis == 2:
+                    if self.concat_indices is None and edge_index.shape[1] is None:
+                        raise ValueError("Cannot infer concat indices, please specify statically in `concat_indices` .")
+                    concat_indices = self.concat_indices if self.concat_indices else range(edge_index.shape[1])
+                    out = tf.concat([out[:, i] for i in concat_indices], axis=1)
+                    return tf.RaggedTensor.from_row_lengths(out, edge_part, validate=self.ragged_validate)
+                # Option: Split features.
+                if self.split_axis == 2:
+                    if self.split_indices is None and edge_index.shape[1] is None:
+                        raise ValueError("Cannot infer split indices, please specify statically in `split_indices` .")
+                    split_indices = self.split_indices if self.split_indices else range(edge_index.shape[1])
+                    return [tf.RaggedTensor.from_row_lengths(
+                        out[:, i], edge_part, validate=self.ragged_validate) for i in split_indices]
+
+                return tf.RaggedTensor.from_row_lengths(out, edge_part, validate=self.ragged_validate)
+        return None
 
     def call(self, inputs, **kwargs):
         r"""Forward pass.
@@ -70,39 +111,38 @@ class GatherEmbedding(GraphBaseLayer):
         Returns:
             tf.RaggedTensor: Gathered node embeddings that match the number of edges of shape `(batch, [M], 2*F)`
         """
-        # The primary case for aggregation of nodes from node feature list. Case from doc-string.
-        # Faster implementation via values and indices shifted by row-partition. Equal to disjoint implementation.
-        if all([isinstance(x, tf.RaggedTensor) for x in inputs]):
-            if all([x.ragged_rank == 1 for x in inputs]) and self.axis == 1 and self.concat_axis in [None, 2] and self.split_axis in [None, 2]:
-                node, node_part = inputs[0].values, inputs[0].row_splits
-                edge_index, edge_part = inputs[1].values, inputs[1].row_lengths()
-                disjoint_list = partition_row_indexing(edge_index, node_part, edge_part,
-                                                       partition_type_target="row_splits",
-                                                       partition_type_index="row_length", to_indexing='batch',
-                                                       from_indexing=self.node_indexing)
-                out = tf.gather(node, disjoint_list, axis=0)
-                if self.concat_axis == 2:
-                    out = tf.concat([out[:, i] for i in range(edge_index.shape[1])], axis=1)
-                    return tf.RaggedTensor.from_row_lengths(out, edge_part, validate=self.ragged_validate)
-                if self.split_axis == 2:
-                    return [tf.RaggedTensor.from_row_lengths(out[:, i], edge_part, validate=self.ragged_validate) for i
-                            in range(edge_index.shape[1])]
-                return tf.RaggedTensor.from_row_lengths(out, edge_part, validate=self.ragged_validate)
+        # Old disjoint implementation that could be faster.
+        out = self._disjoint_implementation(inputs, **kwargs)
+        if out is not None:
+            return out
 
         # For arbitrary gather from ragged tensor use tf.gather with batch_dims=1.
-        # Works in tf.__version__>=2.4 now!
+        # Works in tf.__version__ >= 2.4 !
         out = tf.gather(inputs[0], inputs[1], batch_dims=1, axis=self.axis)
+
+        # Option: Concat features.
         if self.concat_axis is not None:
-            out = tf.concat([tf.gather(out, i, axis=self.concat_axis) for i in range(out.shape[self.concat_axis])],
-                            axis=self.concat_axis)
+            if self.concat_indices is None and out.shape[self.concat_axis] is None:
+                raise ValueError("Cannot infer concat indices, please specify statically in `concat_indices` .")
+            concat_indices = self.concat_indices if self.concat_indices else range(out.shape[self.concat_axis])
+            out = tf.concat(
+                [tf.gather(out, i, axis=self.concat_axis) for i in concat_indices],
+                axis=self.concat_axis
+            )
+        # Option: Split features.
         if self.split_axis is not None:
-            out = [tf.gather(out, i, axis=self.split_axis) for i in range(out.shape[self.split_axis])]
+            if self.split_indices is None and out.shape[self.split_axis] is None:
+                raise ValueError("Cannot infer split indices, please specify statically in `split_indices` .")
+            split_indices = self.split_indices if self.split_indices else range(out.shape[self.split_axis])
+            out = [tf.gather(out, i, axis=self.split_axis) for i in split_indices]
         return out
 
     def get_config(self):
         """Update layer config."""
         config = super(GatherEmbedding, self).get_config()
-        config.update({"concat_axis": self.concat_axis, "axis": self.axis, "split_axis": self.split_axis})
+        config.update({"concat_axis": self.concat_axis, "axis": self.axis, "split_axis": self.split_axis,
+                       "concat_indices": self.concat_indices, "split_indices": self.split_indices,
+                       "node_indexing": self.node_indexing})
         return config
 
 
@@ -190,8 +230,9 @@ class GatherEmbeddingSelection(GraphBaseLayer):
                 return out
 
         # For arbitrary gather from ragged tensor use tf.gather with batch_dims=1.
+        # Works in tf.__version__>=2.4
         out = [tf.gather(inputs[0], tf.gather(inputs[1], i, axis=self.axis_indices), batch_dims=1, axis=self.axis) for i
-               in self.selection_index]  # Works in tf.__version__>=2.4
+               in self.selection_index]
         return out
 
     def get_config(self):
@@ -289,6 +330,7 @@ class GatherState(GraphBaseLayer):
     like for example:
 
     .. math::
+
         \mathbf{h}_i = \mathbf{h}_i \oplus \mathbf{s}
 
     where this layer only repeats :math:`\mathbf{s}` to match a ragged embedding tensor :math:`\mathbf{h}_i`.
