@@ -1,5 +1,6 @@
 import math
 import numpy as np
+from typing import Union
 import tensorflow as tf
 from kgcnn.layers.base import GraphBaseLayer
 from kgcnn.layers.gather import GatherNodesSelection, GatherState
@@ -80,11 +81,11 @@ class ShiftPeriodicLattice(GraphBaseLayer):
     :math:`\vec{n} = (n_1, n_2, n_3)`, then this layer is supposed to return:
 
     .. math::
+
         \vec{x} = \vec{x_0} + n_1\vec{a}_1 + n_2\vec{a}_2 + n_3\vec{a}_3 = \vec{x_0} + \vec{n} \mathbf{a}
 
     The layer expects ragged tensor input for :math:`\vec{x_0}` and :math:`\vec{n}` with multiple positions and their
     images but a single (tensor) lattice matrix per sample.
-
     """
 
     def __init__(self, **kwargs):
@@ -129,6 +130,7 @@ class EuclideanNorm(GraphBaseLayer):
     This amounts for a specific :obj:`axis` along which to sum the coordinates:
 
     .. math::
+
         ||\mathbf{x}||_2 = \sqrt{\sum_i x_i^2}
 
     Vector based edge or node coordinates are defined by `(batch, [N], ..., D)` with last dimension `D`.
@@ -199,7 +201,7 @@ class EuclideanNorm(GraphBaseLayer):
         Returns:
             tf.RaggedTensor: Euclidean norm computed for specific axis of shape `(batch, [N], ...)`
         """
-        return self.call_on_values_tensor_of_ragged(
+        return self.map_values(
             self._compute_euclidean_norm, inputs,
             axis=self.axis, keepdims=self.keepdims, invert_norm=self.invert_norm, add_eps=self.add_eps,
             no_nan=self.no_nan, square_norm=self.square_norm)
@@ -220,6 +222,7 @@ class ScalarProduct(GraphBaseLayer):
     The layer simply does for positions :
 
     .. math::
+
         <\vec{a}, \vec{b}> = \vec{a} \cdot \vec{b} = \sum_i a_i b_i
 
     Code example:
@@ -269,7 +272,7 @@ class ScalarProduct(GraphBaseLayer):
         Returns:
             tf.RaggedTensor: Scalar product of shape `(batch, [N], ...)`
         """
-        return self.call_on_values_tensor_of_ragged(self._scalar_product, inputs, axis=self.axis)
+        return self.map_values(self._scalar_product, inputs, axis=self.axis)
 
     def get_config(self):
         """Update config."""
@@ -285,11 +288,11 @@ class NodeDistanceEuclidean(GraphBaseLayer):
     Let :math:`\vec{x}_1` and :math:`\vec{x}_2` be the position of two nodes, then the output is given by:
 
     .. math::
+
         || \vec{x}_1 - \vec{x}_2 ||_2.
 
     Calls :obj:`EuclideanNorm` on the difference of the inputs, which are position of nodes in space and for example
     the output of :obj:`NodePosition`.
-
     """
 
     def __init__(self, add_eps: bool = False, no_nan: bool = True, **kwargs):
@@ -332,6 +335,7 @@ class EdgeDirectionNormalized(GraphBaseLayer):
     the normalized distance is given by:
 
     .. math::
+
         \frac{\vec{r}_{ij}}{||r_{ij}||} = \frac{\vec{r}_{i} - \vec{r}_{j}}{||\vec{r}_{i} - \vec{r}_{j}||}.
 
     Note that the difference is defined here as :math:`\vec{r}_{i} - \vec{r}_{j}`.
@@ -386,13 +390,14 @@ class VectorAngle(GraphBaseLayer):
     mark vector directions of :math:`i\leftarrow j, j \leftarrow k`.
 
     .. note::
+
         However, this layer directly takes the vector :math:`\vec{v}_1` and :math:`\vec{v}_2` as input.
 
     The angle :math:`\theta` is computed via:
 
     .. math::
-        \theta = \tan^{-1} \; \frac{\vec{v}_1 \cdot \vec{v}_2}{|| \vec{v}_1 \times \vec{v}_2 ||}
 
+        \theta = \tan^{-1} \; \frac{\vec{v}_1 \cdot \vec{v}_2}{|| \vec{v}_1 \times \vec{v}_2 ||}
     """
 
     def __init__(self, **kwargs):
@@ -433,7 +438,7 @@ class VectorAngle(GraphBaseLayer):
         Returns:
             tf.RaggedTensor: Calculated Angle between vector 1 and 2 of shape `(batch, [M], 1)`.
         """
-        return self.call_on_values_tensor_of_ragged(self._compute_vector_angle, inputs)
+        return self.map_values(self._compute_vector_angle, inputs)
 
     def get_config(self):
         """Update config."""
@@ -448,12 +453,14 @@ class EdgeAngle(GraphBaseLayer):
     The vectors :math:`\vec{v}_1` and :math:`\vec{v}_2` span an angles as:
 
     .. math::
+
         \theta = \tan^{-1} \; \frac{\vec{v}_1 \cdot \vec{v}_2}{|| \vec{v}_1 \times \vec{v}_2 ||}
 
     The geometric angle is computed between edge tuples of index :math:`(i, j)`, where :math`:i, j` refer to two edges.
     The edge features are consequently a geometric vector (3D-space) for each edge.
 
     .. note::
+
         Here, the indices :math:`(i, j)` refer to edges and not to node positions!
 
     The layer uses :obj:`GatherEmbeddingSelection` and :obj:`VectorAngle` to compute angles.
@@ -492,7 +499,7 @@ class EdgeAngle(GraphBaseLayer):
         """
         v1, v2 = self.layer_gather_vectors(inputs)
         if self.vector_scale:
-            v1, v2 = [self.call_on_values_tensor_of_ragged(self._scale_vector, x, scale=self._tf_vec_scale[i]) for i, x
+            v1, v2 = [self.map_values(self._scale_vector, x, scale=self._tf_vec_scale[i]) for i, x
                       in enumerate([v1, v2])]
         return self.layer_angle([v1, v2])
 
@@ -511,6 +518,7 @@ class GaussBasisLayer(GraphBaseLayer):
     The distance :math:`d_{ij} = || \mathbf{r}_i - \mathbf{r}_j ||` is expanded in radial basis functions:
 
     .. math::
+
         e_k(\mathbf{r}_i - \mathbf{r}_j) = \exp{(- \gamma || d_{ij} - \mu_k ||^2 )}
 
     where :math:`\mu_k` represents centers located at originally :math:`0\le \mu_k \le 30  \mathring{A}`
@@ -520,7 +528,6 @@ class GaussBasisLayer(GraphBaseLayer):
     :math:`\gamma = \frac{1}{2\sigma^2}`. The Gaussian, or the :math:`\mu_k`, is placed equally
     between :obj:`offset` and :obj:`distance` and the spacing can be defined by the number of :obj:`bins` that is
     simply '(distance-offset)/bins'. The width is controlled by the layer argument :obj:`sigma`.
-
     """
 
     def __init__(self, bins: int = 20, distance: float = 4.0, sigma: float = 0.4, offset: float = 0.0,
@@ -574,7 +581,7 @@ class GaussBasisLayer(GraphBaseLayer):
         Returns:
             tf.RaggedTensor: Expanded distance. Shape is `(batch, [K], bins)`.
         """
-        return self.call_on_values_tensor_of_ragged(
+        return self.map_values(
             self._compute_gauss_basis, inputs,
             offset=self.offset, gamma=self.gamma, bins=self.bins, distance=self.distance)
 
@@ -588,49 +595,98 @@ class GaussBasisLayer(GraphBaseLayer):
 @ks.utils.register_keras_serializable(package='kgcnn', name='FourierBasisLayer')
 class PositionEncodingBasisLayer(GraphBaseLayer):
     r"""Expand a distance into a Positional Encoding basis from `Transformer <https://arxiv.org/pdf/1706.03762.pdf>`_
-    models, with :math:`\sin()` and :math:`\sin()` functions, adapted to distance-like positions.
+    models, with :math:`\sin()` and :math:`\cos()` functions, which was slightly adapted for geometric distance
+    information in edge features.
 
+    The original encoding is defined in `<https://arxiv.org/pdf/1706.03762.pdf>`_ as:
 
+    .. math::
+
+        PE_{(pos,2i)} & = \sin(pos/10000^{2i/d_{model}}) \\\\
+        PE_{(pos,2i+1)} & = \cos(pos/10000^{2i/d_{model}} )
+
+    where :math:`pos` is the position and :math:`i` is the dimension. That is, each dimension of the positional encoding
+    corresponds to a sinusoid. The wavelengths form a geometric progression from :math:`2\pi` to
+    :math:`10000 \times 2\pi`.
+
+    In the definition of this layer we chose a formulation with :math:`x := pos`, wavelength :math:`\lambda` and
+    :math:`i = 0 \dots d_{h}` with :math:`d_h := d_{model}/2` in the form :math:`\sin(\frac{2 \pi}{\lambda} x)`:
+
+    .. math::
+
+        \sin(x/10000^{2i/d_{model}}) = \sin(x \; 2\pi \; / (2\pi \, 10000^{i/d_{h}}))
+        \equiv \sin(x \frac{2 \pi}{\lambda})
+
+    and consequently :math:`\lambda = 2\pi \, 10000^{i/d_{h}}`. Inplace of :math:`2 \pi`, :math:`d_h` and
+    :math:`N=10000` this layer has parameters :obj:`wave_length_min`, :obj:`dim_half` and :obj:`num_mult`.
+    Whether :math:`\sin()` and :math:`\cos()` has to be mixed as in the original definition can be controlled by
+    :obj:`interleave_sin_cos`, which is `False` by default.
     """
 
-    def __init__(self, dim_half: int = 8, wave_length: float = 10, include_frequencies: bool = False, **kwargs):
+    def __init__(self, dim_half: int = 10, wave_length_min: float = 1, num_mult: Union[float, int] = 100,
+                 include_frequencies: bool = False, interleave_sin_cos: bool = False, **kwargs):
         r"""Initialize :obj:`FourierBasisLayer` layer.
 
-        Args:
-            dim_half (int): Dimension of the half output embedding space. Final basis will be 2 * `dim_half`, or
-                even 3 * `dim_half`, if `include_frequencies` is set to `True`. Defaults to 8.
-            wave_length (float): Wavelength for positional sin and cos expansion. Defaults to 10.0.
-            include_frequencies (bool): Whether to also include the frequencies. Default is False.
+        The actual output-dimension will be :math:`2 \times` :obj:`dim_half` or
+        :math:`3 \times` :obj:`dim_half` , if including frequencies. The half output dimension must be larger than 1.
 
+        .. note::
+
+            In the original definition, defaults are :obj:`wave_length_min` = :math:`2 \pi` , :obj:`num_mult` = 10000,
+            and :obj:`interleave_sin_cos` = True.
+
+        Args:
+            dim_half (int): Dimension of the half output embedding space. Defaults to 10.
+            wave_length_min (float): Wavelength for positional sin and cos expansion. Defaults to 1.
+            num_mult (int, float): Number of the geometric expansion multiplier. Default is 100.
+            include_frequencies (bool): Whether to also include the frequencies. Default is False.
+            interleave_sin_cos (bool): Whether to interleave sin and cos terms as in the original definition of the
+                layer. Default is False.
         """
         super(PositionEncodingBasisLayer, self).__init__(**kwargs)
-        # Layer variables
         self.dim_half = dim_half
-        self.wave_length = wave_length
+        self.num_mult = num_mult
+        self.wave_length_min = wave_length_min
         self.include_frequencies = include_frequencies
+        self.interleave_sin_cos = interleave_sin_cos
+        if self.num_mult <= 1:
+            raise ValueError("`num_mult` must be >1. Reduce `wave_length_min` if necessary.")
+        if self.dim_half <= 1:
+            raise ValueError("`dim_half` must be > 1.")
         # Note: For arbitrary axis the code must be adapted.
 
     @staticmethod
-    def _compute_fourier_encoding(inputs,
-                                  dim_half: int = 4, wave_length: float = 10.0, include_frequencies: bool = False):
+    def _compute_fourier_encoding(inputs, dim_half: int = 10, wave_length_min: float = 1,
+                                  num_mult: Union[float, int] = 100, include_frequencies: bool = False,
+                                  interleave_sin_cos: bool = False):
         r"""Expand into fourier basis.
 
         Args:
             inputs (tf.Tensor, tf.RaggedTensor): Tensor input with position or distance to expand into encodings.
-            dim_half (int): Dimension of the half output embedding space.
-            include_frequencies (float): Whether to add
+                Tensor must have a broadcastable dimension at last axis, e.g. shape (N, 1). Tensor must be type 'float'.
+            dim_half (int): Dimension of the half output embedding space. Defaults to 10.
+            wave_length_min (float): Wavelength for positional sin and cos expansion. Defaults to 1.
+            num_mult (int, float): Number of the geometric expansion multiplier. Default is 100.
+            include_frequencies (bool): Whether to also include the frequencies. Default is False.
+            interleave_sin_cos (bool): Whether to interleave sin and cos terms as in the original definition of the
+                layer. Default is False.
 
         Returns:
             tf.Tensor: Distance tensor expanded in Fourier basis.
         """
-        k = -math.log(wave_length)
-        steps = tf.range(dim_half, dtype=inputs.dtype) / dim_half
-        freq = tf.exp(k * steps)
-        scales = tf.cast(freq, dtype=inputs.dtype) * 2 * math.pi
+        steps = tf.range(dim_half, dtype=inputs.dtype) / (dim_half - 1)
+        log_num = tf.constant(-math.log(num_mult), dtype=inputs.dtype)
+        log_wave = tf.constant(-math.log(wave_length_min), dtype=inputs.dtype)
+        freq = tf.exp(log_num * steps + log_wave)  # tf.exp is better than power.
+        scales = tf.cast(freq, dtype=inputs.dtype) * math.pi * 2.0
         arg = inputs * scales
-        # We would have to make an alternate, concatenate via additional axis and flatten it after,
-        # but it is unclear, why this would make a difference for subsequent NN.
-        out = tf.concat([tf.math.sin(arg), tf.math.cos(arg)], dim=-1)
+        if interleave_sin_cos:
+            out = tf.concat(
+                [tf.math.sin(tf.expand_dims(arg, axis=-1)), tf.math.cos(tf.expand_dims(arg, axis=-1))], axis=-1)
+            out = tf.reshape(
+                out, tf.concat([tf.shape(out)[:-2], tf.expand_dims(tf.shape(out)[-2] * 2, axis=-1)], axis=0))
+        else:
+            out = tf.concat([tf.math.sin(arg), tf.math.cos(arg)], axis=-1)
         if include_frequencies:
             out = tf.concat([out, freq], dim=-1)
         return out
@@ -644,22 +700,23 @@ class PositionEncodingBasisLayer(GraphBaseLayer):
         Returns:
             tf.RaggedTensor: Expanded distance. Shape is `(batch, [K], bins)`.
         """
-        return self.call_on_values_tensor_of_ragged(
-            self._compute_fourier_encoding, inputs,
-            dim_half=self.dim_half, wave_length=self.wave_length, include_frequencies=self.include_frequencies)
+        return self.map_values(
+            self._compute_fourier_encoding, inputs, dim_half=self.dim_half, wave_length_min=self.wave_length_min,
+            num_mult=self.num_mult, include_frequencies=self.include_frequencies,
+            interleave_sin_cos=self.interleave_sin_cos)
 
     def get_config(self):
         """Update config."""
         config = super(PositionEncodingBasisLayer, self).get_config()
-        config.update({"dim_half": self.dim_half,
-                       "wave_length": self.wave_length, "include_frequencies": self.include_frequencies})
+        config.update({"dim_half": self.dim_half, "wave_length_min": self.wave_length_min, "num_mult": self.num_mult,
+                       "include_frequencies": self.include_frequencies, "interleave_sin_cos": self.interleave_sin_cos})
         return config
 
 
 @ks.utils.register_keras_serializable(package='kgcnn', name='BesselBasisLayer')
 class BesselBasisLayer(GraphBaseLayer):
     r"""Expand a distance into a Bessel Basis with :math:`l=m=0`, according to
-    `Klicpera et al. (2020) <https://arxiv.org/abs/2011.14115>`_.
+    `Gasteiger et al. (2020) <https://arxiv.org/abs/2011.14115>`_.
 
     For :math:`l=m=0` the 2D spherical Fourier-Bessel simplifies to
     :math:`\Psi_{\text{RBF}}(d)=a j_0(\frac{z_{0,n}}{c}d)` with roots at :math:`z_{0,n} = n\pi`. With normalization
@@ -667,6 +724,7 @@ class BesselBasisLayer(GraphBaseLayer):
     :math:`\tilde{e}_{\text{RBF}} \in \mathbb{R}^{N_{\text{RBF}}}`:
 
     .. math::
+
         \tilde{e}_{\text{RBF}, n} (d) = \sqrt{\frac{2}{c}} \frac{\sin{\left(\frac{n\pi}{c} d\right)}}{d}
 
     Additionally, applies an envelope function :math:`u(d)` for continuous differentiability on the basis
@@ -674,6 +732,7 @@ class BesselBasisLayer(GraphBaseLayer):
     By Default this is a polynomial of the form:
 
     .. math::
+
         u(d) = 1 − \frac{(p + 1)(p + 2)}{2} d^p + p(p + 2)d^{p+1} − \frac{p(p + 1)}{2} d^{p+2},
 
     where :math:`p \in \mathbb{N}_0` and typically :math:`p=6`.
@@ -701,7 +760,7 @@ class BesselBasisLayer(GraphBaseLayer):
         self.envelope_type = str(envelope_type)
 
         if self.envelope_type not in ["poly"]:
-            raise ValueError("Unknown envelope type %s in BesselBasisLayer." % self.envelope_type)
+            raise ValueError("Unknown envelope type '%s' in `BesselBasisLayer`." % self.envelope_type)
 
         # Initialize frequencies at canonical positions.
         def freq_init(shape, dtype):
@@ -736,7 +795,7 @@ class BesselBasisLayer(GraphBaseLayer):
         Returns:
             tf.RaggedTensor: Expanded distance. Shape is `(batch, [K], num_radial)`.
         """
-        return self.call_on_values_tensor_of_ragged(self.expand_bessel_basis, inputs)
+        return self.map_values(self.expand_bessel_basis, inputs)
 
     def get_config(self):
         """Update config."""
@@ -754,14 +813,13 @@ class CosCutOffEnvelope(GraphBaseLayer):
     For edge-like distance :math:`R_{ij}` and cutoff radius :math:`R_c` the envelope :math:`f_c` is given by:
 
     .. math::
+
         f_c(R_{ij}) = 0.5 [\cos{\frac{\pi R_{ij}}{R_c}} + 1]
 
     This layer only computes the cutoff envelope but does not apply it.
     """
 
-    def __init__(self,
-                 cutoff,
-                 **kwargs):
+    def __init__(self, cutoff, **kwargs):
         r"""Initialize layer.
 
         Args:
@@ -789,7 +847,7 @@ class CosCutOffEnvelope(GraphBaseLayer):
         Returns:
             tf.RaggedTensor: Cutoff envelope of shape `(batch, [M], 1)`.
         """
-        return self.call_on_values_tensor_of_ragged(self._compute_cutoff_envelope, inputs, cutoff=self.cutoff)
+        return self.map_values(self._compute_cutoff_envelope, inputs, cutoff=self.cutoff)
 
     def get_config(self):
         """Update config."""
@@ -806,6 +864,7 @@ class CosCutOff(GraphBaseLayer):
     For edge-like distance :math:`R_{ij}` and cutoff radius :math:`R_c` the envelope :math:`f_c` is given by:
 
     .. math::
+
         f_c(R_{ij}) = 0.5 [\cos{\frac{\pi R_{ij}}{R_c}} + 1]
 
     This layer computes the cutoff envelope and applies it to the input by simply multiplying with the envelope.
@@ -839,7 +898,7 @@ class CosCutOff(GraphBaseLayer):
         Returns:
             tf.RaggedTensor: Cutoff applied to input of shape `(batch, [M], D)`.
         """
-        return self.call_on_values_tensor_of_ragged(self._compute_cutoff, inputs, cutoff=self.cutoff)
+        return self.map_values(self._compute_cutoff, inputs, cutoff=self.cutoff)
 
     def get_config(self):
         """Update config."""
@@ -903,8 +962,17 @@ class DisplacementVectorsASU(GraphBaseLayer):
 
 @ks.utils.register_keras_serializable(package='kgcnn', name='DisplacementVectorsUnitCell')
 class DisplacementVectorsUnitCell(GraphBaseLayer):
-    """TODO: Add docs.
+    r"""Computes displacements vectors for edges that require the sending node to be displaced or translated
+    into an image of the unit cell in a periodic system.
 
+    with node position :math:`\vec{x}` , edge :math:`e_{ij}` and the shift or translation vector :math:`\vec{m}_{ij}`
+    the operation of :obj:`DisplacementVectorsUnitCell` performs:
+
+     .. math::
+
+        \vec{d}_{ij} = \vec{x}_i - (\vec{x}_j + \vec{m}_{ij})
+
+    The direction follows the default index conventions of :obj:`NodePosition` layer.
     """
 
     def __init__(self, **kwargs):
@@ -931,13 +999,9 @@ class DisplacementVectorsUnitCell(GraphBaseLayer):
         Returns:
             tf.RaggedTensor: Displacement vector for edges of shape `(batch, [M], 3)`.
         """
-        frac_coords = inputs[0]
-        edge_indices = inputs[1]
-        cell_translations = inputs[2]
-
+        frac_coords, edge_indices, cell_translations = inputs[0], inputs[1], inputs[2]
         # Gather sending and receiving coordinates.
         in_frac_coords, out_frac_coords = self.gather_node_positions([frac_coords, edge_indices], **kwargs)
-
         # Cell translation
         out_frac_coords = self.lazy_add([out_frac_coords, cell_translations], **kwargs)
         offset = self.lazy_sub([in_frac_coords, out_frac_coords], **kwargs)
@@ -946,8 +1010,18 @@ class DisplacementVectorsUnitCell(GraphBaseLayer):
 
 @ks.utils.register_keras_serializable(package='kgcnn', name='FracToRealCoordinates')
 class FracToRealCoordinates(GraphBaseLayer):
-    """TODO: Add docs.
+    r"""Layer to compute real-space coordinates from fractional coordinates and the lattice matrix.
 
+    With lattice matrix :math:`\mathbf{A}` of a periodic lattice with lattice vectors
+    :math:`\mathbf{A} = (\vec{a}_1 , \vec{a}_2 , \vec{a}_3)` and fractional coordinates
+    :math:`\vec{f} = (f_1, f_2, f_3)` the layer performs for each node and with a lattice matrix per sample:
+
+    .. math::
+
+        \vec{r} = \vec{f} \; \mathbf{A}
+
+    Note that the definition of the lattice matrix has lattice vectors in rows, which is the default definition from
+    :obj:`pymatgen`.
     """
 
     def __init__(self, **kwargs):
@@ -971,7 +1045,7 @@ class FracToRealCoordinates(GraphBaseLayer):
         Returns:
             tf.RaggedTensor: Real-space node coordinates of shape `(batch, [N], 3)`.
         """
-        frac_coords = inputs[0]
+        frac_coords = self.assert_ragged_input_rank(inputs[0], ragged_rank=1)
         lattice_matrices = inputs[1]
         lattice_matrices_ = tf.repeat(lattice_matrices, frac_coords.row_lengths(), axis=0)
         real_coords = tf.einsum('ij,ikj->ik', frac_coords.values, lattice_matrices_)
