@@ -9,17 +9,132 @@ logging.basicConfig()
 module_logger = logging.getLogger(__name__)
 module_logger.setLevel(logging.INFO)
 
+
+# OpenBabel can not be installed with pip but conda only. It is an optional dependency at the moment.
+# There was a problem with OpenBabel not finding the 'BABEL_DATADIR'. One can set it manually with
+# python `os.environ['BABEL_DATADIR'] = ...` .
 if "BABEL_DATADIR" not in os.environ:
     module_logger.warning(
         "System variable 'BABEL_DATADIR' is not set. Please set `os.environ['BABEL_DATADIR'] = ...` manually.")
 
 
 class MolecularGraphOpenBabel(MolGraphInterface):
-    r"""A graph object representing a strict molecular graph, e.g. only chemical bonds."""
+    r"""A graph object representing a strict molecular graph, e.g. only chemical bonds.
+    This class is an interface to :obj:`OBMol` class to retrieve graph properties.
 
-    atom_fun_dict = {}
-    mol_fun_dict = {}
-    bond_fun_dict = {}
+    .. code-block:: python
+
+        import numpy as np
+        from kgcnn.mol.graph_babel import MolecularGraphOpenBabel
+        mg = MolecularGraphOpenBabel()
+        mg.from_smiles("CC(C)C(C(=O)O)N")
+        mg.add_hs()
+        mg.make_conformer()
+        mg.optimize_conformer()
+        mg.compute_partial_charges()
+        print(MolecularGraphOpenBabel.atom_fun_dict.keys(), MolecularGraphOpenBabel.bond_fun_dict.keys())
+        print(mg.node_coordinates)
+        print(mg.edge_indices)
+        print(mg.node_attributes(properties=["NumBonds", "GasteigerCharge"], encoder={}))
+
+    """
+
+    atom_fun_dict = {
+        "IsInRing": lambda atom: atom.IsInRing(),
+        "IsPeriodic": lambda atom: atom.IsPeriodic(),
+        "IsHetAtom": lambda atom: atom.IsHetAtom(),
+        "IsAxial": lambda atom: atom.IsAxial(),
+        "IsMetal": lambda atom: atom.IsMetal(),
+        "IsAmideNitrogen": lambda atom: atom.IsAmideNitrogen(),
+        "IsAromatic": lambda atom: atom.IsAromatic(),
+        "IsAromaticNOxide": lambda atom: atom.IsAromaticNOxide(),
+        "IsCarboxylOxygen": lambda atom: atom.IsCarboxylOxygen(),
+        "IsChiral": lambda atom: atom.IsChiral(),
+        "IsHbondAcceptor": lambda atom: atom.IsHbondAcceptor(),
+        "IsHbondAcceptorSimple": lambda atom: atom.IsHbondAcceptorSimple(),
+        "IsHbondDonor": lambda atom: atom.IsHbondDonor(),
+        "IsHbondDonorH": lambda atom: atom.IsHbondDonorH(),
+        "IsHeteroatom": lambda atom: atom.IsHeteroatom(),
+        "IsInRingSize6": lambda atom: atom.IsInRingSize(6),
+        "IsInRingSize5": lambda atom: atom.IsInRingSize(5),
+        "IsNitroOxygen": lambda atom: atom.IsNitroOxygen(),
+        "IsNonPolarHydrogen": lambda atom: atom.IsNonPolarHydrogen(),
+        "IsPhosphateOxygen": lambda atom: atom.IsPhosphateOxygen(),
+        "IsPolarHydrogen": lambda atom: atom.IsPolarHydrogen(),
+        "IsSulfateOxygen": lambda atom: atom.IsSulfateOxygen(),
+        "Visit": lambda atom: atom.Visit,
+        "Isotope": lambda atom: atom.GetIsotope(),
+        "Data": lambda bond: bond.GetData(),
+        "X": lambda bond: bond.GetX(),
+        "Y": lambda bond: bond.GetY(),
+        "Z": lambda bond: bond.GetZ(),
+        "ExplicitValence": lambda bond: bond.GetExplicitValence(),
+        "TotalDegree": lambda bond: bond.GetTotalDegree(),
+        "AtomicMass": lambda bond: bond.GetAtomicMass(),
+        "AtomicNum": lambda bond: bond.GetAtomicNum(),
+        "Coordinate": lambda bond: bond.GetCoordinate(),
+        "CoordinateIdx": lambda bond: bond.GetCoordinateIdx(),
+        "ExactMass": lambda bond: bond.GetExactMass(),
+        "ExplicitDegree": lambda bond: bond.GetExplicitDegree(),
+        "FormalCharge": lambda bond: bond.GetFormalCharge(),
+        "HeteroDegree": lambda bond: bond.GetHeteroDegree(),
+        "HvyDegree": lambda bond: bond.GetHvyDegree(),
+        "Hyb": lambda bond: bond.GetHyb(),
+        "ImplicitHCount": lambda bond: bond.GetImplicitHCount(),
+        "Index": lambda bond: bond.GetIndex(),
+        "PartialCharge": lambda bond: bond.GetPartialCharge(),
+        "Residue": lambda bond: bond.GetResidue(),
+        "SpinMultiplicity": lambda bond: bond.GetSpinMultiplicity(),
+        "Title": lambda bond: bond.GetTitle(),
+        "TotalValence": lambda bond: bond.GetTotalValence(),
+        "Type": lambda bond: bond.GetType(),
+        "Vector": lambda bond: bond.GetVector(),
+        "HasResidue": lambda bond: bond.HasResidue(),
+        "HasDoubleBond": lambda bond: bond.HasDoubleBond(),
+        "HasSingleBond": lambda bond: bond.HasSingleBond(),
+        "HasAromaticBond": lambda bond: bond.HasAromaticBond(),
+        "HasAlphaBetaUnsat": lambda bond: bond.HasAlphaBetaUnsat(),
+        "HasBondOfOrder3": lambda bond: bond.HasBondOfOrder(3),
+        "HasBondOfOrder2": lambda bond: bond.HasBondOfOrder(2),
+        "HasBondOfOrder1": lambda bond: bond.HasBondOfOrder(1),
+        "HasNonSingleBond": lambda bond: bond.HasNonSingleBond()
+    }
+    bond_fun_dict = {
+        "BondOrder": lambda bond: bond.GetBondOrder(),
+        "IsAromatic": lambda bond: bond.IsAromatic(),
+        "IsInRing": lambda bond: bond.IsInRing(),
+        "Idx": lambda bond: bond.GetIdx(),
+        "Id": lambda bond: bond.GetId(),
+        "BeginAtom": lambda bond: bond.GetBeginAtom(),
+        "BeginAtomIdx": lambda bond: bond.GetBeginAtomIdx(),
+        "EndAtom": lambda bond: bond.GetEndAtom(),
+        "EndAtomIdx": lambda bond: bond.GetEndAtomIdx(),
+        "Flags": lambda bond: bond.GetFlags(),
+        "Parent": lambda bond: bond.GetParent(),
+        "Length": lambda bond: bond.GetLength(),
+        "EquibLength": lambda bond: bond.GetEquibLength(),
+        "Aromatic": lambda bond: bond.Aromatic,
+        "CisOrTrans": lambda bond: bond.CisOrTrans,
+        "IsHash": lambda bond: bond.IsHash(),
+        "IsAmide": lambda bond: bond.IsAmide(),
+        "IsEster": lambda bond: bond.IsEster(),
+        "IsCarbonyl": lambda bond: bond.IsCarbonyl(),
+        "IsCisOrTrans": lambda bond: bond.IsCisOrTrans(),
+        "IsClosure": lambda bond: bond.IsClosure(),
+        "IsDoubleBondGeometry": lambda bond: bond.IsDoubleBondGeometry(),
+        "IsPeriodic": lambda bond: bond.IsPeriodic(),
+        "IsPrimaryAmide": lambda bond: bond.IsPrimaryAmide(),
+        "IsTertiaryAmide": lambda bond: bond.IsTertiaryAmide(),
+        "IsWedge": lambda bond: bond.IsWedge(),
+        "IsWedgeOrHash": lambda bond: bond.IsWedgeOrHash(),
+        "Visit": lambda bond: bond.Visit,
+    }
+    mol_fun_dict = {
+        "NumAtoms": lambda m: m.NumAtoms(),
+        "NumBonds": lambda m: m.NumBonds(),
+        "ExactMass": lambda m: m.GetExactMass(),
+        "TotalCharge": lambda m: m.GetTotalCharge(),
+    }
 
     def __init__(self, mol=None, make_directed: bool = False):
         """Set the mol attribute for composition. This mol instances will be the backends molecule class.
@@ -32,28 +147,57 @@ class MolecularGraphOpenBabel(MolGraphInterface):
         self.mol = mol
 
     def make_conformer(self, **kwargs):
+        r"""Make conformer for mol-object.
+
+        Args:
+            kwargs: Not used.
+
+        Returns:
+            bool: Whether conformer generation was successful
+        """
         if self.mol is None:
             return False
-        builder = openbabel.OBBuilder(**kwargs)
+        builder = openbabel.OBBuilder()
         build_okay = builder.Build(self.mol)
         return build_okay
 
-    def optimize_conformer(self):
+    def optimize_conformer(self, force_field="mmff94", steps=100, **kwargs):
+        r"""Optimize conformer. Requires an initial conformer. See :obj:`make_conformer`.
+
+        Args:
+            force_field (str): Force field type.
+            steps (int): Number of iteration steps.
+            kwargs: Kwargs for SteepestDescent.
+
+        Returns:
+            bool: Whether conformer optimization was successful.
+        """
         if self.mol is None:
             return False
-        ff = openbabel.OBForceField.FindType("mmff94")
+        ff = openbabel.OBForceField.FindType(force_field)
         ff_setup_okay = ff.Setup(self.mol)
-        ff.SteepestDescent(100)  # defaults are 50-500 in pybel
+        ff.SteepestDescent(steps, **kwargs)  # defaults are 50-500 in pybel
         ff.GetCoordinates(self.mol)
         return ff_setup_okay
 
     def add_hs(self, **kwargs):
+        """Add Hydrogen."""
         self.mol.AddHydrogens(**kwargs)
 
     def remove_hs(self, **kwargs):
+        """Remove Hydrogen."""
         self.mol.DeleteHydrogens(**kwargs)
 
-    def compute_charges(self, method="gasteiger", **kwargs):
+    def compute_partial_charges(self, method="gasteiger", **kwargs):
+        """Compute partial charges.
+
+        Args:
+            method (str): Name of charge model.
+            kwargs: Not used.
+
+        Returns:
+            bool: Compute charges return value.
+        """
         mol = self.mol
         ob_charge_model = openbabel.OBChargeModel.FindType(method)
         return ob_charge_model.ComputeCharges(mol)
@@ -158,25 +302,6 @@ class MolecularGraphOpenBabel(MolGraphInterface):
             return
         return np.array(xyz)
 
-    @staticmethod
-    def _sort_bonds(bond_idx, bond_info=None):
-        # Sort directed bonds
-        bond_idx = np.array(bond_idx, dtype="int64")
-        bonds1, bonds2 = None, None
-        if len(bond_idx) > 0:
-            order1 = np.argsort(bond_idx[:, 1], axis=0, kind='mergesort')  # stable!
-            ind1 = bond_idx[order1]
-            if bond_info:
-                bonds1 = [bond_info[i] for i in order1]
-            order2 = np.argsort(ind1[:, 0], axis=0, kind='mergesort')  # stable!
-            ind2 = ind1[order2]
-            if bond_info:
-                bonds2 = [bonds1[i] for i in order2]
-            # Take the sorted bonds
-            bond_idx = ind2
-            bond_info = bonds2
-        return bond_idx, bond_info
-
     @property
     def edge_indices(self):
         """Return a list of edge indices of the molecule."""
